==> viqi_api-0.6.4.5-py3-none-any.whl: vqapi/services/factory.py <==

import logging

from vqapi.plugins import find_plugins, filter_classes

from .base_proxy import FuturizedServiceProxy

log = logging.getLogger("vqapi.services")

# SERVICE_PROXIES = {
#     "admin": AdminProxy,
#     "auths": AuthProxy,
#     "blobs": BlobProxy,
#     "meta": DataProxy,
#     "mexes": MexProxy,
#     "datasets": DatasetProxy,
#     "import": ImportProxy,
#     "tables": TableProxy,
#     "pixels": ImageProxy,
#     "dirs": DirProxy,
#     "services": BaseServiceProxy,
#     "futures": FutureProxy,
# }

def import_proxies(name, module):
    """Filter for transfer plugins modules for classes with attribute 'transfer_method'"""
    return [(cls.service_name, cls) for nm, cls in filter_classes(name, module) if hasattr(cls, "service_name")]

class ServiceFactory:

    SERVICE_PROXIES = dict(find_plugins(".", import_proxies))

    # new unified service names (allow all variants for now)
    # TODO: change once all service names are final
    RENAMED_SERVICES = {
        "image_service": "pixels",
        "data_service": "meta",
        "dataset_service": "datasets",
        "auth_service": "auths",
        "preference": "preferences",
        "table": "tables",
        "pipeline": "pipelines",
        "blob_service": "blobs",
        "mex_service": "mexes",
    }

    @classmethod
    def make(cls, session, service_name):
        # translate to new service name
        service_name = cls.RENAMED_SERVICES.get(service_name, service_name)
        svc = cls.SERVICE_PROXIES.get(service_name, FuturizedServiceProxy)
        if session.service_map and service_name not in session.service_map:
            return None
        service_url = session.service_map[service_name]
        return svc(session, service_url)

==> viqi_api-0.6.4.10-py3-none-any.whl: vqapi/services/factory.py <==

import logging

from vqapi.plugins import find_plugins, filter_classes

from .base_proxy import FuturizedServiceProxy

log = logging.getLogger("vqapi.services")

# SERVICE_PROXIES = {
#     "admin": AdminProxy,
#     "auths": AuthProxy,
#     "blobs": BlobProxy,
#     "meta": DataProxy,
#     "mexes": MexProxy,
#     "datasets": DatasetProxy,
#     "import": ImportProxy,
#     "tables": TableProxy,
#     "pixels": ImageProxy,
#     "dirs": DirProxy,
#     "services": BaseServiceProxy,
#     "futures": FutureProxy,
# }

def import_proxies(name, module):
    """Filter for transfer plugins modules for classes with attribute 'transfer_method'"""
    return [(cls.service_name, cls) for nm, cls in filter_classes(name, module) if hasattr(cls, "service_name")]

class ServiceFactory:

    SERVICE_PROXIES = dict(find_plugins(".", import_proxies))

    # new unified service names (allow all variants for now)
    # TODO: change once all service names are final
    RENAMED_SERVICES = {
        "image_service": "pixels",
        "data_service": "meta",
        "dataset_service": "datasets",
        "auth_service": "auths",
        "preference": "preferences",
        "table": "tables",
        "pipeline": "pipelines",
        "blob_service": "blobs",
        "mex_service": "mexes",
    }

    @classmethod
    def make(cls, session, service_name):
        # translate to new service name
        service_name = cls.RENAMED_SERVICES.get(service_name, service_name)
        svc = cls.SERVICE_PROXIES.get(service_name, FuturizedServiceProxy)
        if session.service_map and service_name not in session.service_map:
            return None
        service = session.service_map[service_name]
        if isinstance(service, str):  #
            service = svc(session, service)
            session.service_map[service_name] = service
        return service
